@@ -1,20 +1,19 @@
 from __future__ import annotations
 
 from functools import lru_cache
-from typing import Dict
 
 from app_model import Application
 
-from ._submenus import SUBMENUS
-from .actions._layer_actions import LAYER_ACTIONS
-from .injection._processors import PROCESSORS
-from .injection._providers import PROVIDERS
+from napari._app_model.actions._layerlist_context_actions import (
+    LAYERLIST_CONTEXT_ACTIONS,
+    LAYERLIST_CONTEXT_SUBMENUS,
+)
 
 APP_NAME = 'napari'
 
 
 class NapariApplication(Application):
-    def __init__(self) -> None:
+    def __init__(self, app_name=APP_NAME) -> None:
         # raise_synchronous_exceptions means that commands triggered via
         # ``execute_command`` will immediately raise exceptions. Normally,
         # `execute_command` returns a Future object (which by definition does not
@@ -22,25 +21,20 @@ class NapariApplication(Application):
         # exceptions with `.result()`, for now, raising immediately should
         # prevent any unexpected silent errors.  We can turn it off later if we
         # adopt asynchronous command execution.
-        super().__init__(APP_NAME, raise_synchronous_exceptions=True)
+        super().__init__(app_name, raise_synchronous_exceptions=True)
 
         self.injection_store.namespace = _napari_names  # type: ignore [assignment]
-        self.injection_store.register(
-            providers=PROVIDERS, processors=PROCESSORS
-        )
 
-        for action in LAYER_ACTIONS:
-            self.register_action(action)
-
-        self.menus.append_menu_items(SUBMENUS)
+        self.register_actions(LAYERLIST_CONTEXT_ACTIONS)
+        self.menus.append_menu_items(LAYERLIST_CONTEXT_SUBMENUS)
 
     @classmethod
-    def get_app(cls) -> NapariApplication:
-        return Application.get_app(APP_NAME) or cls()
+    def get_app(cls, app_name: str = APP_NAME) -> NapariApplication:
+        return Application.get_app(app_name) or cls()  # type: ignore[return-value]
 
 
 @lru_cache(maxsize=1)
-def _napari_names() -> Dict[str, object]:
+def _napari_names() -> dict[str, object]:
     """Napari names to inject into local namespace when evaluating type hints."""
     import napari
     from napari import components, layers, viewer
