@@ -41,9 +41,9 @@ from qtpy.QtWidgets import (
 )
 from superqt import QRangeSlider
 
-from ...utils.io import imsave
-from ..qt_resources import get_stylesheet
-from ..utils import QImg2array
+from napari._qt.qt_resources import get_stylesheet
+from napari._qt.utils import QImg2array
+from napari.utils.io import imsave
 
 blurb = """
 <h3>Heading</h3>
@@ -59,7 +59,7 @@ officia deserunt mollit anim id est laborum.</p>
 
 
 class TabDemo(QTabWidget):
-    def __init__(self, parent=None, emphasized=False):
+    def __init__(self, parent=None, emphasized=False) -> None:
         super().__init__(parent)
         self.setProperty('emphasized', emphasized)
         self.tab1 = QWidget()
@@ -67,28 +67,28 @@ class TabDemo(QTabWidget):
         self.tab2 = QWidget()
         self.tab2.setProperty('emphasized', emphasized)
 
-        self.addTab(self.tab1, "Tab 1")
-        self.addTab(self.tab2, "Tab 2")
+        self.addTab(self.tab1, 'Tab 1')
+        self.addTab(self.tab2, 'Tab 2')
         layout = QFormLayout()
-        layout.addRow("Height", QSpinBox())
-        layout.addRow("Weight", QDoubleSpinBox())
-        self.setTabText(0, "Tab 1")
+        layout.addRow('Height', QSpinBox())
+        layout.addRow('Weight', QDoubleSpinBox())
+        self.setTabText(0, 'Tab 1')
         self.tab1.setLayout(layout)
 
         layout2 = QFormLayout()
         sex = QHBoxLayout()
-        sex.addWidget(QRadioButton("Male"))
-        sex.addWidget(QRadioButton("Female"))
-        layout2.addRow(QLabel("Sex"), sex)
-        layout2.addRow("Date of Birth", QLineEdit())
-        self.setTabText(1, "Tab 2")
+        sex.addWidget(QRadioButton('Male'))
+        sex.addWidget(QRadioButton('Female'))
+        layout2.addRow(QLabel('Sex'), sex)
+        layout2.addRow('Date of Birth', QLineEdit())
+        self.setTabText(1, 'Tab 2')
         self.tab2.setLayout(layout2)
 
-        self.setWindowTitle("tab demo")
+        self.setWindowTitle('tab demo')
 
 
 class SampleWidget(QWidget):
-    def __init__(self, theme='dark', emphasized=False):
+    def __init__(self, theme='dark', emphasized=False) -> None:
         super().__init__(None)
         self.setProperty('emphasized', emphasized)
         self.setStyleSheet(get_stylesheet(theme))
@@ -133,10 +133,10 @@ class SampleWidget(QWidget):
         prog = QProgressBar()
         prog.setValue(50)
         lay.addWidget(prog)
-        group_box = QGroupBox("Exclusive Radio Buttons")
-        radio1 = QRadioButton("&Radio button 1")
-        radio2 = QRadioButton("R&adio button 2")
-        radio3 = QRadioButton("Ra&dio button 3")
+        group_box = QGroupBox('Exclusive Radio Buttons')
+        radio1 = QRadioButton('&Radio button 1')
+        radio2 = QRadioButton('R&adio button 2')
+        radio3 = QRadioButton('Ra&dio button 3')
         radio1.setChecked(True)
         hbox = QHBoxLayout()
         hbox.addWidget(radio1)
@@ -153,11 +153,12 @@ class SampleWidget(QWidget):
         return QImg2array(img)
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
+    import logging
     import sys
 
-    from ...utils.theme import available_themes
-    from ..qt_event_loop import get_app
+    from napari._qt.qt_event_loop import get_app
+    from napari.utils.theme import available_themes
 
     themes = [sys.argv[1]] if len(sys.argv) > 1 else available_themes()
     app = get_app()
@@ -166,7 +167,7 @@ if __name__ == "__main__":
         try:
             w = SampleWidget(theme)
         except KeyError:
-            print(f"{theme} is not a recognized theme")
+            logging.warning('%s is not a recognized theme', theme)
             continue
         w.setGeometry(10 + 430 * n, 0, 425, 600)
         w.show()
