@@ -5,10 +5,13 @@ on a layer in the LayerList.
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, List, cast
+import warnings
+from typing import TYPE_CHECKING, cast
 
 import numpy as np
+import numpy.typing as npt
 
+from napari import layers
 from napari.layers import Image, Labels, Layer
 from napari.layers._source import layer_source
 from napari.layers.utils import stack_utils
@@ -19,18 +22,18 @@ if TYPE_CHECKING:
     from napari.components import LayerList
 
 
-def _duplicate_layer(ll: LayerList, *, name: str = ''):
+def _duplicate_layer(ll: LayerList, *, name: str = '') -> None:
     from copy import deepcopy
 
     for lay in list(ll.selection):
         data, state, type_str = lay.as_layer_data_tuple()
-        state["name"] = trans._('{name} copy', name=lay.name)
+        state['name'] = trans._('{name} copy', name=lay.name)
         with layer_source(parent=lay):
             new = Layer.create(deepcopy(data), state, type_str)
         ll.insert(ll.index(lay) + 1, new)
 
 
-def _split_stack(ll: LayerList, axis: int = 0):
+def _split_stack(ll: LayerList, axis: int = 0) -> None:
     layer = ll.selection.active
     if not isinstance(layer, Image):
         return
@@ -43,21 +46,46 @@ def _split_stack(ll: LayerList, axis: int = 0):
     ll.selection = set(images)  # type: ignore
 
 
-def _split_rgb(ll: LayerList):
+def _split_rgb(ll: LayerList) -> None:
     return _split_stack(ll)
 
 
-def _convert(ll: LayerList, type_: str):
+def _convert(ll: LayerList, type_: str) -> None:
     from napari.layers import Shapes
 
     for lay in list(ll.selection):
         idx = ll.index(lay)
-        ll.pop(idx)
         if isinstance(lay, Shapes) and type_ == 'labels':
             data = lay.to_labels()
+            idx += 1
+        elif (
+            not np.issubdtype(lay.data.dtype, np.integer) and type_ == 'labels'
+        ):
+            data = lay.data.astype(int)
+            idx += 1
         else:
-            data = lay.data.astype(int) if type_ == 'labels' else lay.data
-        new_layer = Layer.create(data, lay._get_base_state(), type_)
+            data = lay.data
+            # int image layer to labels is fully reversible
+            ll.pop(idx)
+        # projection mode may not be compatible with new type,
+        # we're ok with dropping it in that case
+        layer_type = getattr(layers, type_.title())
+        state = lay._get_base_state()
+        try:
+            layer_type._projectionclass(state['projection_mode'].value)
+        except ValueError:
+            state['projection_mode'] = 'none'
+            warnings.warn(
+                trans._(
+                    'projection mode "{mode}" is not compatible with {type_} layers. Falling back to "none".',
+                    mode=state['projection_mode'],
+                    type_=type_.title(),
+                    deferred=True,
+                ),
+                category=UserWarning,
+                stacklevel=1,
+            )
+        new_layer = Layer.create(data, state, type_)
         ll.insert(idx, new_layer)
 
 
@@ -66,17 +94,17 @@ def _convert(ll: LayerList, type_: str):
 # so that inject_dependencies works correctly.
 # however, we could conceivably add an `args` option to register_action
 # that would allow us to pass additional arguments, like a partial.
-def _convert_to_labels(ll: LayerList):
+def _convert_to_labels(ll: LayerList) -> None:
     return _convert(ll, 'labels')
 
 
-def _convert_to_image(ll: LayerList):
+def _convert_to_image(ll: LayerList) -> None:
     return _convert(ll, 'image')
 
 
-def _merge_stack(ll: LayerList, rgb=False):
+def _merge_stack(ll: LayerList, rgb: bool = False) -> None:
     # force selection to follow LayerList ordering
-    imgs = cast(List[Image], [layer for layer in ll if layer in ll.selection])
+    imgs = cast(list[Image], [layer for layer in ll if layer in ll.selection])
     assert all(isinstance(layer, Image) for layer in imgs)
     merged = (
         stack_utils.merge_rgb(imgs)
@@ -88,7 +116,7 @@ def _merge_stack(ll: LayerList, rgb=False):
     ll.append(merged)
 
 
-def _toggle_visibility(ll: LayerList):
+def _toggle_visibility(ll: LayerList) -> None:
     current_visibility_state = []
     for layer in ll.selection:
         current_visibility_state.append(layer.visible)
@@ -98,29 +126,51 @@ def _toggle_visibility(ll: LayerList):
             layer.visible = not visibility
 
 
-def _link_selected_layers(ll: LayerList):
+def _show_selected(ll: LayerList) -> None:
+    for lay in ll.selection:
+        lay.visible = True
+
+
+def _hide_selected(ll: LayerList) -> None:
+    for lay in ll.selection:
+        lay.visible = False
+
+
+def _show_unselected(ll: LayerList) -> None:
+    for lay in ll:
+        if lay not in ll.selection:
+            lay.visible = True
+
+
+def _hide_unselected(ll: LayerList) -> None:
+    for lay in ll:
+        if lay not in ll.selection:
+            lay.visible = False
+
+
+def _link_selected_layers(ll: LayerList) -> None:
     ll.link_layers(ll.selection)
 
 
-def _unlink_selected_layers(ll: LayerList):
+def _unlink_selected_layers(ll: LayerList) -> None:
     ll.unlink_layers(ll.selection)
 
 
-def _select_linked_layers(ll: LayerList):
+def _select_linked_layers(ll: LayerList) -> None:
     linked_layers_in_list = [
         x for x in get_linked_layers(*ll.selection) if x in ll
     ]
     ll.selection.update(linked_layers_in_list)
 
 
-def _convert_dtype(ll: LayerList, mode='int64'):
+def _convert_dtype(ll: LayerList, mode: npt.DTypeLike = 'int64') -> None:
     if not (layer := ll.selection.active):
         return
 
     if not isinstance(layer, Labels):
         raise NotImplementedError(
             trans._(
-                "Data type conversion only implemented for labels",
+                'Data type conversion only implemented for labels',
                 deferred=True,
             )
         )
@@ -132,7 +182,7 @@ def _convert_dtype(ll: LayerList, mode='int64'):
     ):
         raise AssertionError(
             trans._(
-                "Labeling contains values outside of the target data type range.",
+                'Labeling contains values outside of the target data type range.',
                 deferred=True,
             )
         )
@@ -140,14 +190,14 @@ def _convert_dtype(ll: LayerList, mode='int64'):
     layer.data = layer.data.astype(np.dtype(mode))
 
 
-def _project(ll: LayerList, axis: int = 0, mode='max'):
+def _project(ll: LayerList, axis: int = 0, mode: str = 'max') -> None:
     layer = ll.selection.active
     if not layer:
         return
     if not isinstance(layer, Image):
         raise NotImplementedError(
             trans._(
-                "Projections are only implemented for images", deferred=True
+                'Projections are only implemented for images', deferred=True
             )
         )
 
@@ -156,11 +206,24 @@ def _project(ll: LayerList, axis: int = 0, mode='max'):
     # before opening up to other layer types, this line should be updated.
     data = (getattr(np, mode)(layer.data, axis=axis, keepdims=False),)
 
-    # get the meta data of the layer, but without transforms
+    # Get the meta-data of the layer, but without transforms,
+    # the transforms are updated bellow as projection of transforms
+    # requires a bit more work than just copying them
+    # (e.g., the axis of the projection should be removed).
+    # It is done in `set_slice` method of `TransformChain`
     meta = {
         key: layer._get_base_state()[key]
         for key in layer._get_base_state()
-        if key not in ('scale', 'translate', 'rotate', 'shear', 'affine')
+        if key
+        not in (
+            'scale',
+            'translate',
+            'rotate',
+            'shear',
+            'affine',
+            'axis_labels',
+            'units',
+        )
     }
     meta.update(  # sourcery skip
         {
