@@ -493,7 +493,7 @@ class Labels(ScalarFieldBase):
             raise ValueError('contour value must be >= 0')
         self._contour = int(contour)
         self.events.contour()
-        self.refresh()
+        self.refresh(extent=False)
 
     @property
     def brush_size(self):
@@ -561,7 +561,7 @@ class Labels(ScalarFieldBase):
         self._color_mode = color_mode
         self.events.colormap()  # Will update the LabelVispyColormap shader
         self.events.selected_label()
-        self.refresh()
+        self.refresh(extent=False)
 
     @property
     def data(self) -> Union[LayerDataProtocol, MultiScaleData]:
@@ -717,7 +717,7 @@ class Labels(ScalarFieldBase):
         self.events.selected_label()
 
         if self.show_selected_label:
-            self.refresh()
+            self.refresh(extent=False)
 
     def swap_selected_and_background_labels(self):
         """Swap between the selected label and the background label."""
@@ -737,7 +737,7 @@ class Labels(ScalarFieldBase):
         self.colormap.use_selection = show_selected
         self.colormap.selection = self.selected_label
         self.events.show_selected_label(show_selected_label=show_selected)
-        self.refresh()
+        self.refresh(extent=False)
 
     # Only overriding to change the docstring
     @property
