@@ -82,7 +82,7 @@ def test_polygon_data_triangle_module():
 
 def test_polygon():
     """Test creating Shape with a random polygon."""
-    # Test a single six vertex polygon
+    # Test a single non convex six vertex polygon
     data = np.array(
         [
             [10.97627008, 14.30378733],
@@ -108,7 +108,7 @@ def test_polygon2():
     shape = Polygon(data, interpolation_order=3)
     # should get many triangles
 
-    expected_face = (249, 2) if 'triangle' in sys.modules else (251, 2)
+    expected_face = (249, 2)
 
     assert shape._edge_vertices.shape == (500, 2)
     assert shape._face_vertices.shape == expected_face
