@@ -48,23 +48,21 @@ to emit events. The EmitterGroup groups EventEmitter objects.
 For more information see http://github.com/vispy/vispy/wiki/API_Events
 
 """
+
 import contextlib
 import inspect
 import os
 import warnings
 import weakref
-from collections.abc import Sequence
+from collections.abc import Iterable, Iterator, Sequence
 from functools import partial
 from typing import (
     Any,
     Callable,
-    Dict,
-    Generator,
-    List,
+    Generic,
     Literal,
     Optional,
-    Tuple,
-    Type,
+    TypeVar,
     Union,
     cast,
 )
@@ -76,7 +74,6 @@ from napari.utils.translations import trans
 
 
 class Event:
-
     """Class describing events that occur and can be reacted to with callbacks.
     Each event instance contains information about a single event that has
     occurred such as a key press, mouse motion, timer activation, etc.
@@ -101,16 +98,16 @@ class Event:
     """
 
     @rename_argument(
-        from_name="type",
-        to_name="type_name",
-        version="0.6.0",
-        since_version="0.4.18",
+        from_name='type',
+        to_name='type_name',
+        version='0.6.0',
+        since_version='0.4.18',
     )
     def __init__(
         self, type_name: str, native: Any = None, **kwargs: Any
     ) -> None:
         # stack of all sources this event has been emitted through
-        self._sources: List[Any] = []
+        self._sources: list[Any] = []
         self._handled: bool = False
         self._blocked: bool = False
         # Store args
@@ -126,7 +123,7 @@ class Event:
         return self._sources[-1] if self._sources else None
 
     @property
-    def sources(self) -> List[Any]:
+    def sources(self) -> list[Any]:
         """List of objects that the event applies to (i.e. are or have
         been a source of the event). Can contain multiple objects in case
         the event traverses a hierarchy of objects.
@@ -141,12 +138,12 @@ class Event:
 
     @property
     def type(self) -> str:
-        # No docstring; documeted in class docstring
+        # No docstring; documented in class docstring
         return self._type
 
     @property
     def native(self) -> Any:
-        # No docstring; documeted in class docstring
+        # No docstring; documented in class docstring
         return self._native
 
     @property
@@ -160,7 +157,7 @@ class Event:
         return self._handled
 
     @handled.setter
-    def handled(self, val) -> bool:
+    def handled(self, val) -> None:
         self._handled = bool(val)
 
     @property
@@ -173,7 +170,7 @@ class Event:
         return self._blocked
 
     @blocked.setter
-    def blocked(self, val) -> bool:
+    def blocked(self, val) -> None:
         self._blocked = bool(val)
 
     def __repr__(self) -> str:
@@ -185,7 +182,7 @@ class Event:
         _event_repr_depth += 1
         try:
             if _event_repr_depth > 2:
-                return "<...>"
+                return '<...>'
             attrs = []
             for name in dir(self):
                 if name.startswith('_'):
@@ -197,7 +194,7 @@ class Event:
                     continue
                 attr = getattr(self, name)
 
-                attrs.append(f"{name}={attr!r}")
+                attrs.append(f'{name}={attr!r}')
         finally:
             _event_repr_depth -= 1
         return f'<{self.__class__.__name__} {" ".join(attrs)}>'
@@ -215,13 +212,16 @@ _event_repr_depth = 0
 
 
 Callback = Union[Callable[[Event], None], Callable[[], None]]
-CallbackRef = Tuple['weakref.ReferenceType[Any]', str]  # dereferenced method
-CallbackStr = Tuple[
+CallbackRef = tuple['weakref.ReferenceType[Any]', str]  # dereferenced method
+CallbackStr = tuple[
     Union['weakref.ReferenceType[Any]', object], str
 ]  # dereferenced method
 
 
-class _WeakCounter:
+_T = TypeVar('_T')
+
+
+class _WeakCounter(Generic[_T]):
     """
     Similar to collection counter but has weak keys.
 
@@ -229,24 +229,25 @@ class _WeakCounter:
     """
 
     def __init__(self) -> None:
-        self._counter = weakref.WeakKeyDictionary()
+        self._counter: weakref.WeakKeyDictionary[_T, int] = (
+            weakref.WeakKeyDictionary()
+        )
         self._nonecount = 0
 
-    def update(self, iterable):
+    def update(self, iterable: Iterable[_T]):
         for it in iterable:
             if it is None:
                 self._nonecount += 1
             else:
                 self._counter[it] = self.get(it, 0) + 1
 
-    def get(self, key, default):
+    def get(self, key: _T, default: int) -> int:
         if key is None:
             return self._nonecount
         return self._counter.get(key, default)
 
 
 class EventEmitter:
-
     """Encapsulates a list of event callbacks.
 
     Each instance of EventEmitter represents the source of a stream of similar
@@ -283,21 +284,21 @@ class EventEmitter:
         The class of events that this emitter will generate.
     """
 
-    @rename_argument("type", "type_name", "0.6.0", "0.4.18")
+    @rename_argument('type', 'type_name', '0.6.0', '0.4.18')
     def __init__(
         self,
         source: Any = None,
         type_name: Optional[str] = None,
-        event_class: Type[Event] = Event,
+        event_class: type[Event] = Event,
     ) -> None:
         # connected callbacks
-        self._callbacks: List[Union[Callback, CallbackRef]] = []
+        self._callbacks: list[Union[Callback, CallbackRef]] = []
         # used when connecting new callbacks at specific positions
-        self._callback_refs: List[Optional[str]] = []
-        self._callback_pass_event: List[bool] = []
+        self._callback_refs: list[Optional[str]] = []
+        self._callback_pass_event: list[bool] = []
 
         # count number of times this emitter is blocked for each callback.
-        self._blocked: Dict[Optional[Callback], int] = {None: 0}
+        self._blocked: dict[Optional[Callback], int] = {None: 0}
         self._block_counter: _WeakCounter[Optional[Callback]] = _WeakCounter()
 
         # used to detect emitter loops
@@ -343,12 +344,7 @@ class EventEmitter:
     @print_callback_errors.setter
     def print_callback_errors(
         self,
-        val: Union[
-            Literal['first'],
-            Literal['reminders'],
-            Literal['always'],
-            Literal['never'],
-        ],
+        val: Literal['first', 'reminders', 'always', 'never'],
     ):
         if val not in ('first', 'reminders', 'always', 'never'):
             raise ValueError(
@@ -360,12 +356,12 @@ class EventEmitter:
         self._print_callback_errors = val
 
     @property
-    def callback_refs(self) -> Tuple[Optional[str], ...]:
+    def callback_refs(self) -> tuple[Optional[str], ...]:
         """The set of callback references"""
         return tuple(self._callback_refs)
 
     @property
-    def callbacks(self) -> Tuple[Union[Callback, CallbackRef], ...]:
+    def callbacks(self) -> tuple[Union[Callback, CallbackRef], ...]:
         """The set of callbacks"""
         return tuple(self._callbacks)
 
@@ -414,9 +410,9 @@ class EventEmitter:
         self,
         callback: Union[Callback, CallbackRef, CallbackStr, 'EventEmitter'],
         ref: Union[bool, str] = False,
-        position: Union[Literal['first'], Literal['last']] = 'first',
-        before: Union[str, Callback, List[Union[str, Callback]], None] = None,
-        after: Union[str, Callback, List[Union[str, Callback]], None] = None,
+        position: Literal['first', 'last'] = 'last',
+        before: Union[str, Callback, list[Union[str, Callback]], None] = None,
+        after: Union[str, Callback, list[Union[str, Callback]], None] = None,
         until: Optional['EventEmitter'] = None,
     ):
         """Connect this emitter to a new callback.
@@ -528,7 +524,7 @@ class EventEmitter:
             callback_bounds = (core_callbacks_count, len(callback_refs))
 
         # bounds: upper & lower bnds (inclusive) of possible cb locs
-        bounds: List[int] = []
+        bounds: list[int] = []
         for ri, criteria in enumerate((before, after)):
             if criteria is None or criteria == []:
                 bounds.append(
@@ -637,7 +633,7 @@ class EventEmitter:
                     return obj, name
             raise RuntimeError(
                 trans._(
-                    "During bind method {callback} of object {obj} an error happen",
+                    'During bind method {callback} of object {obj} an error happen',
                     deferred=True,
                     callback=callback,
                     obj=obj,
@@ -656,7 +652,7 @@ class EventEmitter:
         if sum(map(_is_pos_arg, parameters_list)) > 1:
             raise RuntimeError(
                 trans._(
-                    "Binning function cannot have more than one positional argument",
+                    'Binning function cannot have more than one positional argument',
                     deferred=True,
                 )
             )
@@ -673,7 +669,7 @@ class EventEmitter:
 
     def _normalize_cb(
         self, callback
-    ) -> Tuple[Union[CallbackRef, Callback], bool]:
+    ) -> tuple[Union[CallbackRef, Callback], bool]:
         # dereference methods into a (self, method_name) pair so that we can
         # make the connection without making a strong reference to the
         # instance.
@@ -735,7 +731,7 @@ class EventEmitter:
 
             _log_event_stack(event)
 
-            rem: List[CallbackRef] = []
+            rem: list[CallbackRef] = []
             for cb, pass_event in zip(
                 self._callbacks[:], self._callback_pass_event[:]
             ):
@@ -749,7 +745,7 @@ class EventEmitter:
                     if cb is None:
                         warnings.warn(
                             trans._(
-                                "Problem with function {old_cb} of {obj} connected to event {self_}",
+                                'Problem with function {old_cb} of {obj} connected to event {self_}',
                                 deferred=True,
                                 old_cb=old_cb[1],
                                 obj=obj,
@@ -778,7 +774,7 @@ class EventEmitter:
             if ps is not self.source:
                 raise RuntimeError(
                     trans._(
-                        "Event source-stack mismatch.",
+                        'Event source-stack mismatch.',
                         deferred=True,
                     )
                 )
@@ -825,7 +821,7 @@ class EventEmitter:
         else:
             raise ValueError(
                 trans._(
-                    "Event emitters can be called with an Event instance or with keyword arguments only.",
+                    'Event emitters can be called with an Event instance or with keyword arguments only.',
                     deferred=True,
                 )
             )
@@ -857,7 +853,7 @@ class EventEmitter:
         if callback not in self._blocked or self._blocked[callback] == 0:
             raise RuntimeError(
                 trans._(
-                    "Cannot unblock {self_} for callback {callback}; emitter was not previously blocked.",
+                    'Cannot unblock {self_} for callback {callback}; emitter was not previously blocked.',
                     deferred=True,
                     self_=self,
                     callback=callback,
@@ -890,9 +886,9 @@ class WarningEmitter(EventEmitter):
 
     def __init__(
         self,
-        message,
-        category=FutureWarning,
-        stacklevel=3,
+        message: str,
+        category: type[Warning] = FutureWarning,
+        stacklevel: int = 3,
         *args,
         **kwargs,
     ) -> None:
@@ -927,7 +923,6 @@ class WarningEmitter(EventEmitter):
 
 
 class EmitterGroup(EventEmitter):
-
     """EmitterGroup instances manage a set of related
     :class:`EventEmitters <vispy.event.EventEmitter>`.
     Its primary purpose is to provide organization for objects
@@ -968,13 +963,13 @@ class EmitterGroup(EventEmitter):
         self,
         source: Any = None,
         auto_connect: bool = False,
-        **emitters: Union[Type[Event], EventEmitter, None],
+        **emitters: Union[type[Event], EventEmitter, None],
     ) -> None:
         EventEmitter.__init__(self, source)
 
         self.auto_connect = auto_connect
-        self.auto_connect_format = "on_%s"
-        self._emitters: Dict[str, EventEmitter] = {}
+        self.auto_connect_format = 'on_%s'
+        self._emitters: dict[str, EventEmitter] = {}
         # whether the sub-emitters have been connected to the group:
         self._emitters_connected: bool = False
         self.add(**emitters)  # type: ignore
@@ -991,7 +986,7 @@ class EmitterGroup(EventEmitter):
         return self._emitters[name]
 
     def __setitem__(
-        self, name: str, emitter: Union[Type[Event], EventEmitter, None]
+        self, name: str, emitter: Union[type[Event], EventEmitter, None]
     ):
         """
         Alias for EmitterGroup.add(name=emitter)
@@ -1001,7 +996,7 @@ class EmitterGroup(EventEmitter):
     def add(
         self,
         auto_connect: Optional[bool] = None,
-        **kwargs: Union[Type[Event], EventEmitter, None],
+        **kwargs: Union[type[Event], EventEmitter, None],
     ):
         """Add one or more EventEmitter instances to this emitter group.
         Each keyword argument may be specified as either an EventEmitter
@@ -1047,7 +1042,9 @@ class EmitterGroup(EventEmitter):
 
             if inspect.isclass(emitter) and issubclass(emitter, Event):  # type: ignore
                 emitter = EventEmitter(
-                    source=self.source, type_name=name, event_class=emitter  # type: ignore
+                    source=self.source,
+                    type_name=name,
+                    event_class=emitter,  # type: ignore
                 )
             elif not isinstance(emitter, EventEmitter):
                 raise RuntimeError(
@@ -1078,11 +1075,11 @@ class EmitterGroup(EventEmitter):
                 emitter.connect(self)
 
     @property
-    def emitters(self) -> Dict[str, EventEmitter]:
+    def emitters(self) -> dict[str, EventEmitter]:
         """List of current emitters in this group."""
         return self._emitters
 
-    def __iter__(self) -> Generator[str, None, None]:
+    def __iter__(self) -> Iterator[str]:
         """
         Iterates over the names of emitters in this group.
         """
@@ -1108,11 +1105,11 @@ class EmitterGroup(EventEmitter):
 
     def connect(
         self,
-        callback: Union[Callback, CallbackRef, 'EmitterGroup'],
+        callback: Union[Callback, CallbackRef, EventEmitter, 'EmitterGroup'],
         ref: Union[bool, str] = False,
-        position: Union[Literal['first'], Literal['last']] = 'first',
-        before: Union[str, Callback, List[Union[str, Callback]], None] = None,
-        after: Union[str, Callback, List[Union[str, Callback]], None] = None,
+        position: Literal['first', 'last'] = 'first',
+        before: Union[str, Callback, list[Union[str, Callback]], None] = None,
+        after: Union[str, Callback, list[Union[str, Callback]], None] = None,
     ):
         """Connect the callback to the event group. The callback will receive
         events from *all* of the emitters in the group.
@@ -1177,12 +1174,11 @@ class EmitterGroup(EventEmitter):
 
 
 class EventBlocker:
-
     """Represents a block for an EventEmitter to be used in a context
     manager (i.e. 'with' statement).
     """
 
-    def __init__(self, target, callback=None) -> None:
+    def __init__(self, target: EventEmitter, callback=None) -> None:
         self.target = target
         self.callback = callback
         self._base_count = target._block_counter.get(callback, 0)
@@ -1201,12 +1197,11 @@ class EventBlocker:
 
 
 class EventBlockerAll:
-
     """Represents a block_all for an EmitterGroup to be used in a context
     manager (i.e. 'with' statement).
     """
 
-    def __init__(self, target) -> None:
+    def __init__(self, target: EmitterGroup) -> None:
         self.target = target
 
     def __enter__(self):
@@ -1255,5 +1250,5 @@ def set_event_tracing_enabled(enabled=True, cfg=None):
         _log_event_stack = _noop
 
 
-if os.getenv("NAPARI_DEBUG_EVENTS", '').lower() in ('1', 'true'):
+if os.getenv('NAPARI_DEBUG_EVENTS', '').lower() in ('1', 'true'):
     set_event_tracing_enabled(True)
